@@ -76,7 +76,7 @@ if ($num_col_tariffe_db < 12) $num_col_tariffe_db = 12;
 for ($num1 = 1 ; $num1 <= $num_col_tariffe_db ; $num1++) {
 $nome_nuova_tariffa = "tariffa" . $num1;
 $query .= ", $nome_nuova_tariffa float8, $nome_nuova_tariffa"."p float8";
-$query2 .= ", $nome_nuova_tariffa varchar(40)";
+$query2 .= ", $nome_nuova_tariffa text";
 } # fine for $num1
 
 $crea_tab = esegui_query($query.")");
