@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -40,7 +40,11 @@ $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 if (!function_exists('tab_a_var')) include("./includes/liberasettimane.php");
 if (!function_exists('dati_tariffe')) include("./includes/funzioni_tariffe.php");
 
-include("./includes/sett_gio.php");
+$inc = @include("./includes/sett_gio.php");
+if (!$inc) {
+$tipo_periodi = esegui_query("select * from $tableanni where idanni = $anno");
+$tipo_periodi = risul_query($tipo_periodi,0,'tipo_periodi');
+} # fine if (!$inc)
 $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
@@ -104,7 +108,7 @@ else {
 # se vi è una regola 2 per la tariffa
 unset($app_regola2_predef);
 if (!$lista_app[$n_t]) {
-$lista_app[$n_t] = trova_app_regola2($tipotariffa[$n_t],$regole2,$num_regole2,$app_regola2_predef,$id_periodo_corrente,$idinizioperiodo,$idfineperiodo,$tipo_periodi,$anno,$tableregole);
+$lista_app[$n_t] = dati_regole2($dati_r2,$app_regola2_predef,$tipotariffa[$n_t],$idinizioperiodo,$idfineperiodo,$id_periodo_corrente,$tipo_periodi,$anno,$tableregole);
 } # fine if (!$lista_app[$n_t])
 
 $id_utente_ins = "";
@@ -209,7 +213,13 @@ $app_richiesti[$id_app_richiesti] = $lista_app_richiesti;
 $idinizioperiodo_vett[$id_app_richiesti] = $idinizioperiodo;
 $idfineperiodo_vett[$id_app_richiesti] = $idfineperiodo;
 $app_richiesti[",numero,"] = $id_app_richiesti;
-if ($num_tipologie > 1 and $prenota_vicine == "SI") $app_richiesti[",vicini,"] = "SI";
+if ($num_tipologie > 1) {
+if (@is_array($prenota_vicine)) {
+$app_richiesti[',vicini,'] = "SI";
+$app_richiesti[',succ_non_vicino,'] = $prenota_vicine;
+} # fine if (@is_array($prenota_vicine))
+elseif ($prenota_vicine == "SI") $app_richiesti[',vicini,'] = "SI";
+} # fine if ($num_tipologie > 1)
 
 if ($id_prenota_imp) {
 if (controlla_num_pos($id_prenota_imp[$n_t]) == "SI") {
@@ -709,7 +719,29 @@ $lista_idfine .= ",".$fineperiodo[$n_t];
 $lista_idprenota = substr($lista_idprenota,1);
 $lista_idini = substr($lista_idini,1);
 $lista_idfine = substr($lista_idfine,1);
-if ($prenota_vicine == "SI") {
+if (@is_array($prenota_vicine)) {
+$lista_idprenota_vett = explode(",",$lista_idprenota);
+$num_idprenota_vett = count($lista_idprenota_vett);
+$num_corr = 0;
+for ($num1 = 0 ; $num1 < $num_idprenota_vett ; $num1++) {
+$idprenota = $lista_idprenota_vett[$num1];
+if ($lista_idprenota_corr) $lista_idprenota_corr .= ",";
+$lista_idprenota_corr .= $idprenota;
+$num_corr++;
+if ($prenota_vicine[$num_corr] or $num1 == ($num_idprenota_vett - 1)) {
+if (strstr($lista_idprenota_corr,",")) {
+$lista_idprenota_corr_vett = explode(",",$lista_idprenota_corr);
+for ($num2 = 0 ; $num2 < count($lista_idprenota_corr_vett) ; $num2++) {
+$idprenota = $lista_idprenota_corr_vett[$num2];
+$idprenota_vicine = substr(str_replace(",".$idprenota.",",",",",".$lista_idprenota_corr.","),1,-1);
+esegui_query("update $tableprenota set idprenota_compagna = '$idprenota_vicine' where idprenota = '$idprenota' ");
+} # fine for $num2
+} # fine if (strstr($lista_idprenota_corr,","))
+$lista_idprenota_corr = "";
+} # fine if ($prenota_vicine[$num_corr] or $num1 == ($num_idprenota_vett - 1))
+} # fine for $num1
+} # fine if (@is_array($prenota_vicine))
+elseif ($prenota_vicine == "SI") {
 $lista_idprenota_vett = explode(",",$lista_idprenota);
 for ($num1 = 0 ; $num1 < count($lista_idprenota_vett) ; $num1++) {
 $idprenota = $lista_idprenota_vett[$num1];
