@@ -304,6 +304,20 @@ case "sempre":  				$messaggio = "always"; break;
 case "chiedere":  				$messaggio = "ask"; break;
 case "posizioni vicine":  			$messaggio = "nearby positions"; break;
 case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
+case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
+case "sicuro":  				$messaggio = "secure"; break;
+case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
+case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
+case "Il codice":  				$messaggio = "The code"; break;
+case "aggiunge":  				$messaggio = "adds"; break;
+case "rimuove":  				$messaggio = "removes"; break;
+case "il":  					$messaggio = "the"; break;
+case "Codice promozionale":  			$messaggio = "Promotional code"; break;
+case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
+case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
+case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
+case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
+case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -344,6 +358,8 @@ case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_ask_for_
 case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
 case "var_nomi_costi_agg_imposti":  		$messaggio = "var_imposed_extra_costs_names"; break;
 case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
+case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
+case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
 case "var_assegna_con_regola2":  		$messaggio = "var_assign_with_rule1"; break;
 case "var_considera_motivazioni_regola1":  	$messaggio = "var_motivations_of_rule1_to_consider"; break;
 case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternative_phrase_for_rule1"; break;
@@ -378,6 +394,7 @@ case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
 case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
 case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
 case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
+case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
 case "var_fr_Valuta_sing":  			$messaggio = "var_phr_Currency_sing"; break;
 case "var_fr_Valuta_plur":  			$messaggio = "var_phr_Currency_plur"; break;
 case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_phr_Check_availability"; break;
@@ -571,6 +588,8 @@ case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
 case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
 case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
+case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
+case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
