@@ -53,6 +53,9 @@ case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The
 case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
 case "per le tariffe":  			$messaggio = "for rates"; break;
 case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
+case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
+case "tra":  					$messaggio = "between"; break;
+case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
