@@ -104,6 +104,15 @@ case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
 case "numero di":  				$messaggio = "the number of"; break;
 case "dalla data":  				$messaggio = "from date"; break;
 case "alla data":  				$messaggio = "to date"; break;
+case "solo nelle ripetizioni degli ospiti":	$messaggio = "only inside repetitions of guests"; break;
+case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "only inside repetitions of extra costs"; break;
+case "solo nelle ripetizioni dei pagamenti":	$messaggio = "only inside repetitions of payments"; break;
+case "solo nelle ripetizioni delle unità":	$messaggio = "only inside repetitions of units"; break;
+case "Condizioni applicate":  			$messaggio = "Conditions applied"; break;
+case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be apllied anymore in these repetitions"; break;
+case "solo nelle ripetizioni dell'array":	$messaggio = "only inside repetitions of array"; break;
+case "prima di con valori negativi":  		$messaggio = "before with negative values"; break;
+case "prima di":  				$messaggio = "before"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
