@@ -397,6 +397,10 @@ case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
 case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
 case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
 case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
+case "La tariffa":  				$messaggio = "Rate"; break;
+case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
