@@ -139,11 +139,11 @@ case "Il numero di":  				$messaggio = "El número de"; break;
 case "richiesto è sbagliato":  			$messaggio = "pedido está equivocado"; break;
 case "in":  					$messaggio = "en"; break;
 case "Totale":  				$messaggio = "Total"; break;
-case "Aggiungi una nuova tipologia":  		$messaggio = "Añade una nueva tipología"; break;
+case "Aggiungi una nuova tipologia":  		$messaggio = "Añadir una nueva tipología"; break;
 case "Numero di colonne dei costi aggiuntivi errato":	$messaggio = "Número de columnas de los costes añadidos equivocado"; break;
 case "Numero di colonne dei costi aggiuntivi":	$messaggio = "Número de columnas de los costes añadidos"; break;
 case "tipologia":  				$messaggio = "tipología"; break;
-case "Elimina questa tipologia":  		$messaggio = "Elimina esta tipología"; break;
+case "Elimina questa tipologia":  		$messaggio = "Eliminar esta tipología"; break;
 case "Scegliere le settimane in cui applicare":	$messaggio = "Escoger las semanas en las que aplicar"; break;
 case "Scegliere i giorni in cui applicare":  	$messaggio = "Escoger los días en las que aplicar"; break;
 case "Chiedere il numero di persone?":  	$messaggio = "Preguntar por el número de personas?"; break;
@@ -304,6 +304,20 @@ case "sempre":  				$messaggio = "siempre"; break;
 case "chiedere":  				$messaggio = "preguntar"; break;
 case "posizioni vicine":  			$messaggio = "posiciones_cercanas"; break;
 case "con posizioni vicine":  			$messaggio = "con posiciones cercanas"; break;
+case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Direcciones alternativas desde donde se puede acceder a la página"; break;
+case "sicuro":  				$messaggio = "segura"; break;
+case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "usar un espacio para no mostrar el coste en los detalles"; break;
+case "Codici promozionali":  			$messaggio = "Códigos promocionales"; break;
+case "Il codice":  				$messaggio = "El código"; break;
+case "aggiunge":  				$messaggio = "añade"; break;
+case "rimuove":  				$messaggio = "elimina"; break;
+case "il":  					$messaggio = "el"; break;
+case "Codice promozionale":  			$messaggio = "Código promicional"; break;
+case "Solo quelli selezionati per essere mostrati":	$messaggio = "Solo los seleccionados para enseñar"; break;
+case "Codice promozionale applicato":  		$messaggio = "Código promicional aplicado"; break;
+case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "algunos costes añadidos con código promicional"; break;
+case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "no están asociados a tarifas, algunas de sus características podrían ser modificadas si no son compatibles"; break;
+case "Mostrare le date passate?":  		$messaggio = "Enseñar las fechas pasadas?"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -344,6 +358,8 @@ case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_pregunta
 case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_costes_agnadidos_a_ensegnar"; break;
 case "var_nomi_costi_agg_imposti":  		$messaggio = "var_nombres_costes_agnadidos_impuestos"; break;
 case "var_categorie_costi_agg_imposte":  	$messaggio = "var_categorias_costes_agnadidos_impuestas"; break;
+case "var_campi_codici_promo":  		$messaggio = "var_campos_codigos_promo"; break;
+case "var_costi_campi_codici_promo":  		$messaggio = "var_costes_campos_codigos_promo"; break;
 case "var_assegna_con_regola2":  		$messaggio = "var_asigna_con_regla1"; break;
 case "var_considera_motivazioni_regola1":  	$messaggio = "var_considera_motivaciones_regla1"; break;
 case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_muestra_frase_alternativa_regla1"; break;
@@ -378,6 +394,7 @@ case "var_tema_modello":  			$messaggio = "var_tema_modelo"; break;
 case "var_colore_tema":  			$messaggio = "var_color_tema"; break;
 case "var_valore_tema":  			$messaggio = "var_valor_tema"; break;
 case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_alinear_disponibilidad_con_llegada"; break;
+case "var_mostra_date_passate":  		$messaggio = "var_ensegnar_fechas_pasadas"; break;
 case "var_fr_Valuta_sing":  			$messaggio = "var_fr_divisa_sing"; break;
 case "var_fr_Valuta_plur":  			$messaggio = "var_fr_divisa_plur"; break;
 case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_fr_Controla_disponibilidad"; break;
@@ -571,6 +588,8 @@ case "var_fr_Accetto":  			$messaggio = "var_fr_Acepto"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_fr_La_tipologia_pedida_esta_cerrada_en_este_periodo"; break;
 case "var_fr_posizioni_vicine":  		$messaggio = "var_fr_posiciones_cercanas"; break;
 case "var_fr_con_posizioni_vicine":  		$messaggio = "var_fr_con_posiciones_cercanas"; break;
+case "var_fr_Codice_promozionale":  		$messaggio = "var_fr_Codigo_promocional"; break;
+case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_fr_Codigo_promocional_aplicado"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
