@@ -41,7 +41,7 @@ case "La caparra è stata modificata":  		$messaggio = "La fianza ha sido modifi
 case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Hay que espicificar cuando aplicar el coste síngulo"; break;
 case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Hay que insertar el nombre del coste añadido"; break;
 case "Il costo aggiuntivo finale":  		$messaggio = "El coste añadido síngulo"; break;
-case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "existe ya, vé a la pagina con todos los periódos y las tarifas para cancelarlo"; break;
+case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "existe ya, vé a la pagina con todos los períodos y las tarifas para cancelarlo"; break;
 case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Para preguntar el número a multiplicar el coste añadido síngulo no tiene que estar aplicado automaticamente"; break;
 case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Hay que espicificar cuando aplicar el coste semanal"; break;
 case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Hay que espicificar cuando aplicar el coste diario"; break;
@@ -304,6 +304,12 @@ case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo per
 case "tutte le tariffe":  			$messaggio = "todas las tarifas"; break;
 case "considerare l'intero costo come tasse":  	$messaggio = "considerar todo el coste como tasas"; break;
 case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Excluir este coste del total para el porcentaje de los otros costes"; break;
+case "in tutti i periodi in modo predefinito":	$messaggio = "en todos los períodos de manera predefinida"; break;
+case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "importa los precios de otras tarifas, no puede exportar sus precios"; break;
+case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "ya importa los precios de otras tarifas en estos períodos, no puede importar otros precios"; break;
+case "modifica":  				$messaggio = "modificar"; break;
+case "In modo predefinito importa":  		$messaggio = "De manera predefinida importar"; break;
+case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "los precios de algunos períodos <em>no han sido insertados</em> porque importados desde otras tarifas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
