@@ -2,7 +2,7 @@
 
 switch ($messaggio) {
 
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Variabili personalizzate dei documenti":  $messaggio = "Variables personalizadas de los documentos"; break;
 case "Variabili personalizzate":  		$messaggio = "Variables personalizadas"; break;
 case "Elimina":  				$messaggio = "Eliminar"; break;
@@ -104,6 +104,15 @@ case "uguale al numero di":  			$messaggio = "igual al número de"; break;
 case "numero di":  				$messaggio = "número de"; break;
 case "dalla data":  				$messaggio = "desde la fecha"; break;
 case "alla data":  				$messaggio = "hasta la fecha"; break;
+case "solo nelle ripetizioni degli ospiti":	$messaggio = "solo en las repeticiones de los huéspedes"; break;
+case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "solo en las repeticiones de los costes añadidos"; break;
+case "solo nelle ripetizioni dei pagamenti":	$messaggio = "solo en las repeticiones de los pagos"; break;
+case "solo nelle ripetizioni delle unità":	$messaggio = "solo en las repeticiones de las unidades"; break;
+case "Condizioni applicate":  			$messaggio = "Condiciones aplicadas"; break;
+case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "todas las otras condiciones ya no serán aplicadas en estas repeticiones"; break;
+case "solo nelle ripetizioni dell'array":	$messaggio = "solo en las repeticiones del array"; break;
+case "prima di con valori negativi":  		$messaggio = "antes de con valores negativos"; break;
+case "prima di":  				$messaggio = "antes de"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
