@@ -397,6 +397,10 @@ case "per ordine di inserimento":  		$messaggio = "por orden de inserción"; bre
 case "Tasti per operazioni nel punto vendita":	$messaggio = "Botones para las operaciones en el punto de venta"; break;
 case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "El orden en el inventario y punto de venta ha sido cambiado"; break;
 case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Los botones para las operaciones en el punto de venta han sido cambiados"; break;
+case "Attenzione":  				$messaggio = "Atención"; break;
+case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "los enlaces para la exportación de los calendarios en formato ical han cambiado, recordarse de actualizarlos en los calendarios externos"; break;
+case "La tariffa":  				$messaggio = "La tarifa"; break;
+case "è ancora in uso nelle interconnessioni":	$messaggio = "está siendo todavía utilizada en las interconexiones"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
