@@ -118,7 +118,7 @@ case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti
 case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "ya no se añadirá ningún <b>prefijo/sufijo</b> a todos los apellidos de los clientes insertados por el usuario"; break;
 case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "El nuevo texto del <b>prefijo/sufijo</b> de los clientes insertados por el usuario"; break;
 case "sarà":  					$messaggio = "será"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "Año <div style=\"display: inline; color: red;\">equivocado</div>"; break;
 case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Horas en las que se puede modificar la reserva <div style=\"display: inline; color: red;\">equivocadas</div>"; break;
 case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Horas en las que se puede borrar la reserva <div style=\"display: inline; color: red;\">equivocadas</div>"; break;
