@@ -154,7 +154,7 @@ case "la conferma":  				$messaggio = "la confimación"; break;
 case "La prenotazione":  			$messaggio = "La reserva"; break;
 case "verrà confermata":  			$messaggio = "será confirmada"; break;
 case "Data di inserimento":  			$messaggio = "Fecha de inserción"; break;
-case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calcula el subtotal de las reservas seleccionadas"; break;
+case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calcular el subtotal de las reservas seleccionadas"; break;
 case "selezionate precedentemente":  		$messaggio = "seleccionadas precedentemente"; break;
 case "Saldo totale":  				$messaggio = "Diferencia total"; break;
 case "l'anno":  				$messaggio = "el año"; break;
@@ -358,6 +358,7 @@ case "chiusa":  				$messaggio = "cerrada"; break;
 case "presenti in data":  			$messaggio = "presentes el"; break;
 case "comprese partenze":  			$messaggio = "incluyendo las salidas"; break;
 case "escludere_da_totale_percentuale":  	$messaggio = "excluir_del_total_para_porcentaje"; break;
+case "da varie tariffe":  			$messaggio = "desde varias<br>tarifas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
