@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -575,13 +575,13 @@ $prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
-$prima_parte_html = preg_replace("/<script +language *= *\"?php\"? *>/i","ERROR",$prima_parte_html);
+$prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
 if (get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
 $ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("%>","ERROR",$ultima_parte_html);
-$ultima_parte_html = preg_replace("/<script +language *= *\"?php\"? *>/i","ERROR",$ultima_parte_html);
+$ultima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$ultima_parte_html);
 # FRASI
 if ($cambia_frasi == "SI" or $modello_esistente == "SI") {
 for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
@@ -857,8 +857,36 @@ else $url_pagina_link = "$percorso_cartella_modello/$nome_file";
 
 if ($silenzio == "NO") echo "<br>";
 if ($silenzio != "totale") echo mex("Una pagina chiamata",$pag)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex("è stata creata nella directory",$pag)." \"$percorso_cartella_modello\".<br>";
-if (defined("C_CARTELLA_CREA_MODELLI") and $silenzio == "NO") echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
-else if ($silenzio == "NO") echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+if ($silenzio == "NO") {
+if (defined("C_CARTELLA_CREA_MODELLI")) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
+else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+
+if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
+$altri_domini = @file(C_FILE_DOMINIO);
+if ($altri_domini) {
+if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
+else $percorso_cartella_dominio = $percorso_cartella_modello;
+if (substr($percorso_cartella_dominio,0,1) == "/") $percorso_cartella_dominio = substr($percorso_cartella_dominio,1);
+if (strcmp($percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
+if (substr($percorso_cartella_dominio,0,2) == "./") $percorso_cartella_dominio = substr($percorso_cartella_dominio,2);
+$lista_altri_domini = "";
+$num_altri_domini = count($altri_domini);
+for ($num1 = 0 ; $num1 < $num_altri_domini ; $num1++) {
+if ($num1 == 0) $altro_dominio = "https://";
+else $altro_dominio = "http://";
+$altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
+if ($altro_dominio != $url_pagina_link) {
+$lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
+if ($num1 == 0) $lista_altri_domini .= " (".mex("sicuro",$pag).")";
+$lista_altri_domini .= "<br>";
+} # fine if ($altro_dominio != $url_pagina_link)
+} # fine for $num1
+if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
+} # fine if ($altri_domini)
+} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")
+
+echo "<br>";
+} # fine if ($silenzio == "NO")
 } # fine if ($file)
 else if ($silenzio == "NO") echo mex("Non ho il permesso di scrittura nella cartella",$pag)." $percorso_cartella_modello.<br>";
 
