@@ -53,11 +53,16 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
+<meta name=\"viewport\" content=\"initial-scale=1.0\">
 <title> $nome_file </title>
 <style type=\"text/css\">
- div.homebox { width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox { width: 100%; padding: 10px 0 10px 0; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox a { padding-left: 20px }
  div.mainbox { text-align: center; padding: 10px; }
  a { color: [theme_color_1]; }
+ @media only screen and (max-width: 720px) {
+  .tab_disp_cont { overflow-x: scroll }
+ }
 </style>
 [theme_value_4]
 </head>
