@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -26,21 +26,22 @@
 $var_mod = "";
 
 $var_mod[0] = "estendi_ultima_data";
-$var_mod[1] = "apertura_tag_font";
-$var_mod[2] = "chiusura_tag_font";
-$var_mod[3] = "periodi_menu";
-$var_mod[4] = "stile_soldi";
-$var_mod[5] = "stile_data";
-$var_mod[6] = "fr_Valuta_sing";
-$var_mod[7] = "fr_Valuta_plur";
-$var_mod[8] = "anteponi_nome_valuta";
-$var_mod[9] = "tariffe_mostra";
-$var_mod[10] = "nomi_tariffe_imposte";
-$var_mod[11] = "costi_aggiuntivi_mostra";
-$var_mod[12] = "nomi_costi_agg_imposti";
-$var_mod[13] = "mostra_caparra";
-$var_mod[14] = "file_css_frame";
-$var_mod[15] = "tema_modello";
+$var_mod[1] = "mostra_date_passate";
+$var_mod[2] = "apertura_tag_font";
+$var_mod[3] = "chiusura_tag_font";
+$var_mod[4] = "periodi_menu";
+$var_mod[5] = "stile_soldi";
+$var_mod[6] = "stile_data";
+$var_mod[7] = "fr_Valuta_sing";
+$var_mod[8] = "fr_Valuta_plur";
+$var_mod[9] = "anteponi_nome_valuta";
+$var_mod[10] = "tariffe_mostra";
+$var_mod[11] = "nomi_tariffe_imposte";
+$var_mod[12] = "costi_aggiuntivi_mostra";
+$var_mod[13] = "nomi_costi_agg_imposti";
+$var_mod[14] = "mostra_caparra";
+$var_mod[15] = "file_css_frame";
+$var_mod[16] = "tema_modello";
 
 $num_var_mod = count($var_mod);
 
@@ -254,6 +255,8 @@ $m_valuta_plur = $fr_Valuta_plur;
 
 if (strtoupper($estendi_ultima_data) == $SI) $estendi_ultima_data = "SI";
 else $estendi_ultima_data = "NO";
+if (strtoupper($mostra_date_passate) == $NO) $mostra_date_passate = "NO";
+else $mostra_date_passate = "SI";
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
@@ -296,7 +299,7 @@ $ultima_parte_html = addslashes($ultima_parte_html);
 
 
 function crea_modello_rat ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi) {
-global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data;
+global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$mostra_date_passate;
 global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane;
 global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$tema_modello;
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
@@ -314,6 +317,7 @@ if (numlin_query($anno_esistente) != 1) $continua = "NO";
 if ($continua != "NO") {
 
 if ($estendi_ultima_data != "SI") $estendi_ultima_data = "NO";
+if ($mostra_date_passate != "NO") $mostra_date_passate = "SI";
 
 $date_in_menu = "";
 $idfineperiodo_prec = -10;
@@ -532,13 +536,13 @@ $prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
-$prima_parte_html = preg_replace("/<script +language *= *\"?php\"? *>/i","ERROR",$prima_parte_html);
+$prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
 if (get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
 $ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("%>","ERROR",$ultima_parte_html);
-$ultima_parte_html = preg_replace("/<script +language *= *\"?php\"? *>/i","ERROR",$ultima_parte_html);
+$ultima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$ultima_parte_html);
 # FRASI
 if ($cambia_frasi == "SI" or $modello_esistente == "SI") {
 for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
@@ -611,6 +615,7 @@ fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed'
 \$".mex("var_stile_data",$pag)." = \"".mex("$m_stile_data",$pag)."\";
 \$".mex("var_anteponi_nome_valuta",$pag)." = \"".mex("$anteponi_nome_valuta",$pag)."\";
 \$".mex("var_estendi_ultima_data",$pag)." = \"".mex("$estendi_ultima_data",$pag)."\";
+\$".mex("var_mostra_date_passate",$pag)." = \"".mex("$mostra_date_passate",$pag)."\";
 \$".mex("var_tariffe_mostra",$pag)." = array($tariffe_mostra);
 \$".mex("var_nomi_tariffe_imposte",$pag)." = array($nomi_tariffe_imposte);
 \$".mex("var_costi_aggiuntivi_mostra",$pag)." = array($costi_attivati);
@@ -697,6 +702,8 @@ if (strtoupper(\$".mex("var_anteponi_nome_valuta",$pag).") == \"".mex("SI",$pag)
 else \$anteponi_nome_valuta = \"NO\";
 if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"".mex("SI",$pag)."\") \$estendi_ultima_data = \"SI\";
 else \$estendi_ultima_data = \"NO\";
+if (strtoupper(\$".mex("var_mostra_date_passate",$pag).") == \"".mex("NO",$pag)."\") \$mostra_date_passate = \"NO\";
+else \$mostra_date_passate = \"SI\";
 unset(\$tariffe_mostra);
 reset (\$".mex("var_tariffe_mostra",$pag).");
 while (list (\$key, \$val) = each (\$".mex("var_tariffe_mostra",$pag).")) {
@@ -803,8 +810,36 @@ else $url_pagina_link = "$percorso_cartella_modello/$nome_file";
 
 if ($silenzio == "NO") echo "<br>";
 if ($silenzio != "totale") echo mex("Una pagina chiamata",$pag)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex("è stata creata nella directory",$pag)." \"$percorso_cartella_modello\".<br>";
-if (defined("C_CARTELLA_CREA_MODELLI") and $silenzio == "NO") echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
-else if ($silenzio == "NO") echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+if ($silenzio == "NO") {
+if (defined("C_CARTELLA_CREA_MODELLI")) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
+else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";
+
+if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
+$altri_domini = @file(C_FILE_DOMINIO);
+if ($altri_domini) {
+if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
+else $percorso_cartella_dominio = $percorso_cartella_modello;
+if (substr($percorso_cartella_dominio,0,1) == "/") $percorso_cartella_dominio = substr($percorso_cartella_dominio,1);
+if (strcmp($percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
+if (substr($percorso_cartella_dominio,0,2) == "./") $percorso_cartella_dominio = substr($percorso_cartella_dominio,2);
+$lista_altri_domini = "";
+$num_altri_domini = count($altri_domini);
+for ($num1 = 0 ; $num1 < $num_altri_domini ; $num1++) {
+if ($num1 == 0) $altro_dominio = "https://";
+else $altro_dominio = "http://";
+$altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
+if ($altro_dominio != $url_pagina_link) {
+$lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
+if ($num1 == 0) $lista_altri_domini .= " (".mex("sicuro",$pag).")";
+$lista_altri_domini .= "<br>";
+} # fine if ($altro_dominio != $url_pagina_link)
+} # fine for $num1
+if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
+} # fine if ($altri_domini)
+} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")
+
+echo "<br>";
+} # fine if ($silenzio == "NO")
 } # fine if ($file)
 else if ($silenzio == "NO") echo mex("Non ho il permesso di scrittura nella cartella",$pag)." $percorso_cartella_modello.<br>";
 
