@@ -53,15 +53,20 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
+<meta name=\"viewport\" content=\"initial-scale=1.0\">
 <title> $nome_file </title>
 <style type=\"text/css\">
- div.homebox { width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox { width: 100%; padding: 10px 0 10px 0; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox a { padding-left: 20px }
  div.mainbox { text-align: center; padding: 10px; }
  .rates { background-color: [theme_color_3]; border-radius: 10px; }
  .rates tr:first-child td:first-child { border-top-left-radius: 10px; }
  .rates tr:first-child td:last-child { border-top-right-radius: 10px; }
  .rates tr:last-child td:first-child { border-bottom-left-radius: 10px; }
  .rates tr:last-child td:last-child { border-bottom-right-radius: 10px; }
+ @media only screen and (max-width: 720px) {
+  .rates_cont { overflow-x: scroll; }
+ }
 </style>
 [theme_value_4]
 </head>
