@@ -53,9 +53,11 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <html>
 <head>
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\">
+<meta name=\"viewport\" content=\"initial-scale=1.0\">
 <title> $nome_file </title>
 <style type=\"text/css\">
- div.homebox { width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox { width: 100%; padding: 10px 0 10px 0; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.homebox a { padding-left: 20px }
  div.mainbox { text-align: center; padding: 10px; }
  table.formframe { margin-left: auto;  margin-right: auto; background-color: [theme_color_3]; border-radius: 14px; }
  table.formframe td { border-radius: 14px; }
@@ -67,6 +69,14 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
  .t_book td {  border-radius: 8px; }
  div.agreem { max-width: 600px; border: 1px solid black; padding: 3px; }
  select { background-color: #ffffff; }
+ @media only screen and (max-width: 480px) {
+  .t_book table, table.extra_costs, [class^=\"phr_separator\"] { display: block; }
+  .t_book table tr, .extra_costs tr { display: block; padding: 5px 0 5px 0; }
+  .t_book table td, .extra_costs td { display: block; text-align: left; padding: 0; }
+ }
+ @media only screen and (max-width: 720px) {
+  input.dbutton { width: 20px; }
+ }
 </style>
 [theme_value_4]
 </head>
