@@ -284,12 +284,13 @@ $var_predef[257] = "testo_quotato_email_richiesta";
 $var_predef[258] = "nome_valuta";
 $var_predef[259] = "ritorno_a_capo";
 $var_predef[260] = "avanzamento_riga";
-$var_predef[261] = "email_gia_inviata";
-$var_predef[262] = "errore_ripetizione";
-$var_predef[263] = "messaggio_di_errore";
+$var_predef[261] = "valore_nullo";
+$var_predef[262] = "email_gia_inviata";
+$var_predef[263] = "errore_ripetizione";
+$var_predef[264] = "messaggio_di_errore";
 
 $num_var_predef = count($var_predef);
-$num_var_non_ripeti = 115;
+$num_var_non_ripeti = 116;
 $num_var_predef_ripeti = $num_var_predef - $num_var_non_ripeti;
 
 if ($num_commenti_pers) {
@@ -397,6 +398,14 @@ $var_riserv['num_condizioni_ini_d'] = 1;
 $var_riserv['condizioni_ini_d'] = 1;
 $var_riserv['num_condizioni_ini_r'] = 1;
 $var_riserv['condizioni_ini_r'] = 1;
+$var_riserv['num_condizioni_rip_o'] = 1;
+$var_riserv['condizioni_rip_o'] = 1;
+$var_riserv['num_condizioni_rip_c'] = 1;
+$var_riserv['condizioni_rip_c'] = 1;
+$var_riserv['num_condizioni_rip_p'] = 1;
+$var_riserv['condizioni_rip_p'] = 1;
+$var_riserv['num_condizioni_rip_u'] = 1;
+$var_riserv['condizioni_rip_u'] = 1;
 $var_riserv['condizione_ini_vett'] = 1;
 $var_riserv['num_condizioni'] = 1;
 $var_riserv['condizione_vett'] = 1;
@@ -465,6 +474,18 @@ $var_riserv['num_cond_ini_r_vett'] = 1;
 $var_riserv['condizione_ini_d_vett'] = 1;
 $var_riserv['azione_ini_d_vett'] = 1;
 $var_riserv['num_cond_ini_d_vett'] = 1;
+$var_riserv['condizione_rip_o_vett'] = 1;
+$var_riserv['azione_rip_o_vett'] = 1;
+$var_riserv['num_cond_rip_o_vett'] = 1;
+$var_riserv['condizione_rip_c_vett'] = 1;
+$var_riserv['azione_rip_c_vett'] = 1;
+$var_riserv['num_cond_rip_c_vett'] = 1;
+$var_riserv['condizione_rip_p_vett'] = 1;
+$var_riserv['azione_rip_p_vett'] = 1;
+$var_riserv['num_cond_rip_p_vett'] = 1;
+$var_riserv['condizione_rip_u_vett'] = 1;
+$var_riserv['azione_rip_u_vett'] = 1;
+$var_riserv['num_cond_rip_u_vett'] = 1;
 $var_riserv['break_cont'] = 1;
 $var_riserv['data_inizio_selezione_f'] = 1;
 $var_riserv['data_fine_selezione_f'] = 1;
@@ -490,6 +511,12 @@ $var_riserv['incr_np'] = 1;
 $var_riserv['filelock'] = 1;
 $var_riserv['data_primo_arrivo'] = 1;
 $var_riserv['data_ultima_partenza'] = 1;
+$var_riserv['condizioni_alternative'] = 1;
+$var_riserv['condizioni_alternative0'] = 1;
+$var_riserv['num_condizioni_corr'] = 1;
+$var_riserv['condizione_vett_corr'] = 1;
+$var_riserv['num_cond_vett_corr'] = 1;
+$var_riserv['azione_vett_corr'] = 1;
 
 
 
