@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -32,7 +32,7 @@ if (!isset($anno)) {
 if (isset($_GET['anno'])) $anno = $_GET['anno'];
 if (isset($_POST['anno'])) $anno = $_POST['anno'];
 if (!isset($anno)) {
-@include(C_DATI_PATH."/versione.php");
+@include_once(C_DATI_PATH."/versione.php");
 $anno = date("Y",(time() + (C_DIFF_ORE * 3600)));
 if (@is_file(C_DATI_PATH."/selectperiodi".($anno + 1).".1.php")) $anno = $anno + 1;
 elseif (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php") and @is_file(C_DATI_PATH."/selectperiodi".($anno - 1).".1.php")) $anno = $anno - 1;
@@ -311,6 +311,11 @@ $lista_regola2[$tariffa]['txt'] = $lista_app;
 $lista_app2 = risul_query($regole2,$num1,'motivazione2');
 $lista_regola2[$tariffa]['txt2'] = $lista_app;
 if ($lista_app and $lista_app2) $lista_regola2[$tariffa]['txt2'] .= ",$lista_app2";
+$lista_regola2[$tariffa]['napp'] = risul_query($regole2,$num1,'motivazione3');
+if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v") {
+$lista_regola2[$tariffa]['vapp'] = 1;
+$lista_regola2[$tariffa]['napp'] = substr($lista_regola2[$tariffa]['napp'],1);
+} # fine if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v")
 } # fine for $num1
 
 
@@ -501,9 +506,10 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"modifica_interconnessione\" value=\"SI\">
 <div style=\"line-height: 1.3;\">
-".mex("Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale",$pag).".<br>
-".mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag).":<br>
-<input type=\"text\" name=\"url_subordinazione\" value=\"http://\" size=60><br>
+".mex("Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale",$pag).".<br>";
+if (C_NASCONDI_MARCA == "SI") echo str_replace("hoteldruid","",mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag)).":<br>";
+else echo mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag).":<br>";
+echo "<input type=\"text\" name=\"url_subordinazione\" value=\"http://\" size=60><br>
 ".ucfirst(mex("amministratore o utente con i privilegi per creare backup",$pag)).":<br>
 <table cellspacing=\"0\"><tr><td style=\"width: 30px;\"></td><td>
 ".ucfirst(mex("nome utente",$pag)).":
