@@ -1576,6 +1576,10 @@ if ($priv_vedi_tab_prenotazioni == "s" or ($priv_vedi_tab_prenotazioni == "p" an
 $numero = risul_query($prenotazioni,$num2,'idprenota',$tablepren_m);
 $appartamento = risul_query($prenotazioni,$num2,'idappartamenti',$tablepren_m);
 $commento = risul_query($prenotazioni,$num2,'commento',$tablepren_m);
+if (strstr($commento,">")) {
+$commento = explode(">",$commento);
+$commento = $commento[0];
+} # fine if (strstr($commento,">"))
 if (!$commento) { $commento = "&nbsp;"; }
 
 $id_data_inizio = risul_query($prenotazioni,$num2,'iddatainizio',$tablepren_m);
