@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -149,6 +149,7 @@ for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $condizione = risul_query($condizioni,$num1,'testo');
 $condizione = explode("#@?",$condizione);
 $elimina_cond_corr = "NO";
+if ($condizione[0] == "rar$arr_pers_elimina") $elimina_cond_corr = "SI";
 if ($condizione[1]) {
 $se_cond = explode("#$?",$condizione[1]);
 $num_se_cond = count($se_cond);
@@ -428,7 +429,13 @@ unlock_tabelle($tabelle_lock);
 if ($aggiungi_cond) {
 $mostra_form_iniziale = "NO";
 $continua = "SI";
-if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind") $continua = "NO";
+if (substr($inizializza,0,1) == "a") {
+$num_arr_rip = substr($inizializza,1);
+$inizializza = "rar$num_arr_rip";
+$arr_esistente = esegui_query("select * from $tablecontratti where (tipo = 'vett' or tipo = 'vett$contr_cond') and numero = '".aggslashdb($num_arr_rip)."'");
+if (numlin_query($arr_esistente) != 1) $continua = "NO";
+} # fine if (substr($inizializza,0,1) == "a")
+if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind" and $inizializza != "ros" and $inizializza != "rca" and $inizializza != "rpa" and $inizializza != "run" and preg_replace("/rar[1-9][0-9]*/","",$inizializza) != "") $continua = "NO";
 if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
 if ($oper_data and $azione = "date") $azione = "opdat";
@@ -511,7 +518,7 @@ $testo .= "set#%?$var_allora#%?$oper_str#%?$tipo_val_allora#%?$val_allora#%?$tip
 } # fine if ($azione == "set")
 if ($azione == "trunc") {
 controlla_var_allora($var_trunc,$continua,$contr_cond);
-if (!$val_trunc or controlla_num_pos($val_trunc) == "NO") $continua = "NO";
+if (!$val_trunc or controlla_num($val_trunc) == "NO") $continua = "NO";
 $val_trunc2 = controlla_testo_input($val_trunc2);
 if ($pos_trunc2 != "ini" and $pos_trunc2 != "fin") $continua = "NO";
 $testo .= "trunc#%?$var_trunc#%?$val_trunc#%?$val_trunc2#%?$pos_trunc2";
@@ -813,21 +820,59 @@ else $rowbgcolor = $t2row2color;
 return $rowbgcolor;
 } # fine function rowbgcolor
 
+$num_rip_a = 0;
+$num_cond_rip_a = array();
+$num_cond_rip_a[1] = 0;
+$ordine_rar = "";
+$condizioni_rar = esegui_query("select * from $tablecontratti where tipo = 'cond$contr_cond' and testo $LIKE 'rar%' order by testo");
+$num_condizioni_rar = numlin_query($condizioni_rar);
+for ($num1 = 0 ; $num1 < $num_condizioni_rar ; $num1++) {
+$cond = risul_query($condizioni_rar,$num1,'testo');
+$num_arr_rip = substr($cond,3,(strlen(strstr($cond,"#@?")) * -1));
+if (!$num_cond_rip_a['num'][$num_arr_rip]) {
+$num_rip_a++;
+$num_cond_rip_a['num'][$num_arr_rip] = $num_rip_a;
+$num_cond_rip_a['arr'][$num_rip_a] = $num_arr_rip;
+$ordine_rar .= ", testo $LIKE 'rar$num_arr_rip%' desc";
+} # fine if (!$num_cond_rip_a['num'][$num_arr_rip])
+} # fine for $num1
+
 $azione_orig = $azione;
 $num_cond_mod_vedi = "";
-$condizioni = esegui_query("select * from $tablecontratti where tipo = 'cond$contr_cond' order by testo $LIKE 'ind%' desc, testo $LIKE 'inr%' desc, numero");
+$condizioni = esegui_query("select * from $tablecontratti where tipo = 'cond$contr_cond' order by testo $LIKE 'ind%' desc, testo $LIKE 'inr%' desc, testo $LIKE 'rpt%' desc, testo $LIKE 'ros%' desc, testo $LIKE 'rca%' desc, testo $LIKE 'rpa%' desc, testo $LIKE 'run%' desc$ordine_rar, numero");
 $num_condizioni = numlin_query($condizioni);
 $num_cond_ini_d = 0;
 $num_cond_ini_r = 0;
+$num_cond_rpt = 0;
+$num_cond_rip_o = 0;
+$num_cond_rip_c = 0;
+$num_cond_rip_p = 0;
+$num_cond_rip_u = 0;
 for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $n_cond = risul_query($condizioni,$num1,'numero');
 $cond = risul_query($condizioni,$num1,'testo');
 if (substr($cond,0,3) == "ind") $num_cond_ini_d = $num1 + 1;
 if (substr($cond,0,3) == "inr") $num_cond_ini_r = $num1 + 1;
+if (substr($cond,0,3) == "rpt") $num_cond_rpt = $num1 + 1;
+if (substr($cond,0,3) == "ros") $num_cond_rip_o = $num1 + 1;
+if (substr($cond,0,3) == "rca") $num_cond_rip_c = $num1 + 1;
+if (substr($cond,0,3) == "rpa") $num_cond_rip_p = $num1 + 1;
+if (substr($cond,0,3) == "run") $num_cond_rip_u = $num1 + 1;
+if (substr($cond,0,3) == "rar") {
+$num_arr_rip = substr($cond,3,(strlen(strstr($cond,"#@?")) * -1));
+$num_cond_rip_a[$num_cond_rip_a['num'][$num_arr_rip]] = $num1 + 1;
+} # fine if (substr($cond,0,3) == "rar")
 if ($n_cond == $num_cond) $num_cond_passa = $num1;
 $cond_vett[$num1] = $n_cond;
 } # fine for $num1
 if ($num_cond_ini_r < $num_cond_ini_d) $num_cond_ini_r = $num_cond_ini_d;
+if ($num_cond_rpt < $num_cond_ini_r) $num_cond_rpt = $num_cond_ini_r;
+if ($num_cond_rip_o < $num_cond_rpt) $num_cond_rip_o = $num_cond_rpt;
+if ($num_cond_rip_c < $num_cond_rip_o) $num_cond_rip_c = $num_cond_rip_o;
+if ($num_cond_rip_p < $num_cond_rip_c) $num_cond_rip_p = $num_cond_rip_c;
+if ($num_cond_rip_u < $num_cond_rip_p) $num_cond_rip_u = $num_cond_rip_p;
+if ($num_cond_rip_a[1] < $num_cond_rip_u) $num_cond_rip_a[1] = $num_cond_rip_u;
+for ($num1 = 1 ; $num1 < $num_rip_a ; $num1++) if ($num_cond_rip_a[($num1 + 1)] < $num_cond_rip_a[$num1]) $num_cond_rip_a[($num1 + 1)] = $num_cond_rip_a[$num1];
 if ($num_cond and $num_cond_passa < 20) echo "<a name=\"condizioni\"></a>";
 echo "<div class=\"rbox\">".mex("<b>Condizioni</b> applicate",$pag)." $frase_cond_contr:<br>
 <table><tr><td style=\"height: 5px;\"></td></tr></table>";
@@ -846,6 +891,13 @@ $azione_orig = $azione[0];
 $num_cond_mod_orig = $num_cond_mod;
 if ($agg_se or $canc_se) $num_cond_mod = "";
 } # fine if ($num_cond_mod == $num_cond)
+
+if ($num1 == $num_cond_rpt and $condizione[0] == "ros") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni degli ospiti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_o and $condizione[0] == "rca") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_c and $condizione[0] == "rpa") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dei pagamenti",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_p and $condizione[0] == "run") $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni delle unità",$pag)." (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+if ($num1 == $num_cond_rip_u and $condizione[0] == "rar".$num_cond_rip_a['arr'][1]) $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][1]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
+for ($num2 = 1 ; $num2 < $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2] and $condizione[0] == "rar".$num_cond_rip_a['arr'][($num2 + 1)]) $tab_cond .= "</table><br>".mex("Condizioni applicate",$pag)." ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".$num_cond_rip_a['arr'][($num2 + 1)]]."] (<em>".mex("tutte le altre condizioni non verranno più applicate in queste ripetizioni",$pag)."</em>):<br><table>";
 $tab_cond .= "<tr style=\"background-color: ".rowbgcolor().";\"><td><b>".($num1 + 1)."</b>. ";
 if ($num_cond_passa == ($num1 + 20)) $tab_cond .= "<a name=\"condizioni\"></a>";
 $str_cond = "";
@@ -919,8 +971,10 @@ else $val_sost2_txt = htmlspecialchars($azione[8]);
 } # fine if ($azione[0] == "set")
 
 if ($azione[0] == "trunc") {
-$str_cond .= mex("troncare",$pag)." [".$nome_var[$azione[1]]."] ".mex("dopo",$pag);
-$str_cond .= " ".$azione[2]." ".mex("caratteri",$pag);
+$str_cond .= mex("troncare",$pag)." [".$nome_var[$azione[1]]."] ";
+if ($azione[2] < 0) $str_cond .= mex("prima di",$pag)." ".($azione[2] * -1);
+else $str_cond .= mex("dopo",$pag)." ".$azione[2];
+$str_cond .= " ".mex("caratteri",$pag);
 if (strcmp($azione[3],"")) {
 $str_cond .= " (".mex("riempiendo i mancanti con",$pag)." \"".htmlspecialchars($azione[3])."\"";
 if ($azione[4] == "ini") $str_cond .= " ".mex("all'inizio",$pag);
@@ -1027,10 +1081,23 @@ if ($azione[0] == "cont") $str_cond .= mex("riprendi a processare le condizioni
 
 if ($condizione[0] == "inr") $str_cond .= " ".mex("solo all'inizio delle ripetizioni delle prenotazioni",$pag);
 if ($condizione[0] == "ind") $str_cond .= " ".mex("solo all'inizio del documento",$pag);
+if ($condizione[0] == "ros") $str_cond .= " ".mex("solo nelle ripetizioni degli ospiti",$pag);
+if ($condizione[0] == "rca") $str_cond .= " ".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag);
+if ($condizione[0] == "rpa") $str_cond .= " ".mex("solo nelle ripetizioni dei pagamenti",$pag);
+if ($condizione[0] == "run") $str_cond .= " ".mex("solo nelle ripetizioni delle unità",$pag);
+if (substr($condizione[0],0,3) == "rar") $str_cond .= " ".mex("solo nelle ripetizioni dell'array",$pag)." [".$nome_var["a".substr($condizione[0],3)]."]";
 $tab_cond .= ucfirst($str_cond).".</td>";
-if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and $num1 != ($num_cond_ini_d - 1)) {
+$fine_cond_rip_a = 0;
+for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 == ($num_cond_rip_a[$num2] - 1)) $fine_cond_rip_a = 1;
+if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and $num1 != ($num_cond_ini_d - 1) and $num1 != ($num_cond_rpt - 1) and $num1 != ($num_cond_rip_o - 1) and $num1 != ($num_cond_rip_c - 1) and $num1 != ($num_cond_rip_p - 1) and $num1 != ($num_cond_rip_u - 1) and !$fine_cond_rip_a) {
 $opt_giu = "";
 $fine_opt = $num_condizioni;
+for ($num2 = $num_rip_a ; $num2 > 0 ; $num2--) if ($num1 < ($num_cond_rip_a[$num2] - 1)) $fine_opt = $num_cond_rip_a[$num2];
+if ($num1 < ($num_cond_rip_u - 1)) $fine_opt = $num_cond_rip_u;
+if ($num1 < ($num_cond_rip_p - 1)) $fine_opt = $num_cond_rip_p;
+if ($num1 < ($num_cond_rip_c - 1)) $fine_opt = $num_cond_rip_c;
+if ($num1 < ($num_cond_rip_o - 1)) $fine_opt = $num_cond_rip_o;
+if ($num1 < ($num_cond_rpt - 1)) $fine_opt = $num_cond_rpt;
 if ($num1 < ($num_cond_ini_r - 1)) $fine_opt = $num_cond_ini_r;
 if ($num1 < ($num_cond_ini_d - 1)) $fine_opt = $num_cond_ini_d;
 for ($num2 = ($num1 + 2) ; $num2 <= $fine_opt ; $num2++) $opt_giu .= "<option value=\"".$cond_vett[($num2 - 1)]."\">$num2</option>";
@@ -1044,13 +1111,21 @@ $input_cond_contr
 <button type=\"submit\">
 <img style=\"display: block;\" src=\"./img/freccia_giu_marg.png\" alt=\"&lt;\">
 </button></td></tr></table></div></form></td>";
-} # fine if ($num1 != ($num_condizioni - 1) and...
+} # fine if ($num1 != ($num_condizioni - 1) and $num1 != ($num_cond_ini_r - 1) and...
 else $tab_cond .= "<td></td>";
-if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d) {
+$fine_cond_rip_a = 0;
+for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 == $num_cond_rip_a[$num2]) $fine_cond_rip_a = 1;
+if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d and $num1 != $num_cond_rpt and $num1 != $num_cond_rip_o and $num1 != $num_cond_rip_c and $num1 != $num_cond_rip_p and $num1 != $num_cond_rip_u and !$fine_cond_rip_a) {
 $opt_su = "";
 $fine_opt = 1;
 if ($num1 > $num_cond_ini_d) $fine_opt = ($num_cond_ini_d + 1);
 if ($num1 > $num_cond_ini_r) $fine_opt = ($num_cond_ini_r + 1);
+if ($num1 > $num_cond_rpt) $fine_opt = ($num_cond_rpt + 1);
+if ($num1 > $num_cond_rip_o) $fine_opt = ($num_cond_rip_o + 1);
+if ($num1 > $num_cond_rip_c) $fine_opt = ($num_cond_rip_c + 1);
+if ($num1 > $num_cond_rip_p) $fine_opt = ($num_cond_rip_p + 1);
+if ($num1 > $num_cond_rip_u) $fine_opt = ($num_cond_rip_u + 1);
+for ($num2 = 1 ; $num2 <= $num_rip_a ; $num2++) if ($num1 > $num_cond_rip_a[$num2]) $fine_opt = ($num_cond_rip_a[$num2] + 1);
 for ($num2 = $num1 ; $num2 >= $fine_opt ; $num2--) $opt_su .= "<option value=\"".$cond_vett[($num2 - 1)]."\">$num2</option>";
 $tab_cond .= "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#condizioni\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1062,7 +1137,7 @@ $input_cond_contr
 <img style=\"display: block;\" src=\"./img/freccia_su_marg.png\" alt=\"&gt;\">
 </button></td><td><select class=\"smallsel\" name=\"salta_a\">$opt_su</select>
 </td></tr></table></div></form></td>";
-} # fine if ($num1 != 0 and ($num1 + 1) != $num_cond_ini)
+} # fine if ($num1 != 0 and $num1 != $num_cond_ini_r and $num1 != $num_cond_ini_d and...
 else $tab_cond .= "<td></td>";
 $tab_cond .= "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#modcond\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1161,9 +1236,22 @@ if ($num_se > 2 and !$and_or) $num_se = 1;
 $sel_rip = "";
 $sel_inirip = "";
 $sel_inidoc = "";
+$sel_iniros = "";
+$sel_inirca = "";
+$sel_inirpa = "";
+$sel_inirun = "";
 if (!$inizializza or $inizializza == "rpt") $sel_rip = " selected";
 if ($inizializza == "inr") $sel_inirip = " selected";
 if ($inizializza == "ind") $sel_inidoc = " selected";
+if ($inizializza == "ros") $sel_iniros = " selected";
+if ($inizializza == "rca") $sel_inirca = " selected";
+if ($inizializza == "rpa") $sel_inirpa = " selected";
+if ($inizializza == "run") $sel_inirun = " selected";
+$option_arr_rip = str_replace("\">","\">".mex("solo nelle ripetizioni dell'array",$pag)." ",$option_arr_pers);
+if (substr($inizializza,0,3) == "rar") {
+$num_arr_rip = substr($inizializza,3);
+$option_arr_rip = str_replace("\"a".$num_arr_rip."\"","\"a".$num_arr_rip."\" selected",$option_arr_rip);
+} # fine if (substr($inizializza,0,3) == "rar")
 echo "<div class=\"rbox\" style=\"padding-top: 8px;\">
 <a name=\"modcond\"></a>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#modcond\"><div>
@@ -1181,6 +1269,11 @@ echo " <select name=\"inizializza\">
 <option value=\"rpt\"$sel_rip>".mex("in tutte le ripetizioni delle prenotazioni",$pag)."</option>
 <option value=\"inr\"$sel_inirip>".mex("solo all'inizio delle ripetizioni delle prenotazioni",$pag)."</option>
 <option value=\"ind\"$sel_inidoc>".mex("solo all'inizio del documento",$pag)."</option>
+<option value=\"ros\"$sel_iniros>".mex("solo nelle ripetizioni degli ospiti",$pag)."</option>
+<option value=\"rca\"$sel_inirca>".mex("solo nelle ripetizioni dei costi aggiuntivi",$pag)."</option>
+<option value=\"rpa\"$sel_inirpa>".mex("solo nelle ripetizioni dei pagamenti",$pag)."</option>
+<option value=\"run\"$sel_inirun>".mex("solo nelle ripetizioni delle unità",$pag)."</option>
+$option_arr_rip
 </select>:<br>
 
 <table>";
@@ -1317,7 +1410,8 @@ echo "<table onclick=\"document.getElementById('az_trunc').checked='1'\"><tr><td
 <input type=\"radio\" id=\"az_trunc\" name=\"azione\" value=\"trunc\"$chk_az>
 </td><td>".ucfirst(mex("troncare",$pag))." </td><td><select name=\"var_trunc\">
 ".str_replace("\"$var_trunc\">","\"$var_trunc\" selected>",$option_var_pers)."
-</select></td><td>".str_replace(" ","&nbsp;",mex("dopo",$pag))."</td><td>
+</select></td><td>".str_replace(" ","&nbsp;",mex("dopo",$pag))."
+<small><small>(".str_replace(" ","&nbsp;",mex("prima di con valori negativi",$pag)).")</small></small></td><td>
 <input type=\"text\" name=\"val_trunc\" value=\"$val_trunc\" size=\"3\" maxlength=\"12\"></td><td>
 ".str_replace(" ","&nbsp;",mex("caratteri",$pag))."</td><td>
 <td>(".str_replace(" ","&nbsp;",mex("se mancanti riempire con",$pag))."</td><td>
