@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -58,7 +58,8 @@ if ($id_utente) {
 
 if (str_replace("-","",$numero_contratto) != $numero_contratto) {
 $numero_contratto = explode("-",$numero_contratto);
-$codice_lingua_1 = $numero_contratto[1];
+if (!$num_ripeti or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
+for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) ${"codice_lingua_".$num1} = $numero_contratto[1];
 $numero_contratto = $numero_contratto[0];
 } # fine if (str_replace("-","",$numero_contratto) != $numero_contratto)
 
@@ -464,6 +465,7 @@ ${"costo_tariffa_".$num1} = $costo_tariffa;
 $sconto = (double) risul_query($dati_prenota,0,'sconto');
 if (strcmp($sconto,"")) ${"sconto_".$num1} = $sconto;
 if (strcmp(risul_query($dati_prenota,0,'tasseperc'),"")) ${"percentuale_tasse_tariffa_".$num1} = risul_query($dati_prenota,0,'tasseperc');
+else ${"percentuale_tasse_tariffa_".$num1} = 0;
 if (strcmp(risul_query($dati_prenota,0,'commento'),"")) ${"commento_".$num1} = risul_query($dati_prenota,0,'commento');
 if (strstr(${"commento_".$num1},">")) {
 $comm = explode(">",${"commento_".$num1});
@@ -496,6 +498,7 @@ $costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
 ${"nome_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['nome'];
 ${"val_costo_agg".$numca."_".$num1} = $costo_agg_parziale;
 if (strcmp($dati_cap[$numca]['tasseperc'],"")) ${"percentuale_tasse_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['tasseperc'];
+else ${"percentuale_tasse_costo_agg".$numca."_".$num1} = 0;
 ${"moltiplica_max_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['moltiplica_costo'];
 if ($dati_cap[$numca]['associasett'] == "s") {
 if ($dati_cap[$numca]['settimane']) ${"giorni_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['settimane'];
